Skip to main contentModule handle
Source Expand description
- persist
- Closed
- Marker to signal the Registration is a closed file that consumes no additional process resources.
- Writable
- Marker to signal the Registration is an open file able to be written to.